#ifndef IRSSI_FE_COMMON_CORE_WINDOWS_LAYOUT_H
#define IRSSI_FE_COMMON_CORE_WINDOWS_LAYOUT_H

void windows_layout_restore(void);
void windows_layout_save(void);
void windows_layout_reset(void);

void windows_layout_init(void);
void windows_layout_deinit(void);

#endif
